@@ -60,6 +60,10 @@
 #define PREF_TRAYICON_BEHAVIOR                  "trayicon_behavior"
 #define PREF_TRAYICON_BEHAVIOR_DEFAULT          0
 
+/* Define the behavior of a double click on a song/album/artist... */
+#define PREF_DOUBLECLICK_BEHAVIOR               "doubleclick_behavior"
+#define PREF_DOUBLECLICK_BEHAVIOR_DEFAULT       0
+
 /* True if the initial assistant has already been run */
 #define PREF_FIRST_TIME                         "first_time_flag"
 #define PREF_FIRST_TIME_DEFAULT                 FALSE
@@ -172,9 +176,21 @@
 #define PREF_DATE_COLUMN_ORDER                  "date_column_order"
 #define PREF_DATE_COLUMN_ORDER_DEFAULT          9
 
+/* Disc column properties */
+#define PREF_DISC_COLUMN_SIZE                   "disc_column_size"
+#define PREF_DISC_COLUMN_SIZE_DEFAULT           70
+#define PREF_DISC_COLUMN_VISIBLE                "disc_column_visible"
+#define PREF_DISC_COLUMN_VISIBLE_DEFAULT        FALSE
+#define PREF_DISC_COLUMN_ORDER                  "disc_column_order"
+#define PREF_DISC_COLUMN_ORDER_DEFAULT          10
+
 /* List of active plugins. It contains the "Location" of the active plugins. See the .ario-plugin file for obtaining the "Location" of a given plugin. */
 #define PREF_PLUGINS_LIST                       "active-plugins"
+#ifdef ENABLE_LIBNOTIFY
+#define PREF_PLUGINS_LIST_DEFAULT               "filesystem,radios,wikipedia,liblibnotify"
+#else
 #define PREF_PLUGINS_LIST_DEFAULT               "filesystem,radios,wikipedia"
+#endif
 
 /* Ordered list of sources */
 #define PREF_SOURCE_LIST                        "sources-order"
@@ -214,7 +230,11 @@
 
 /* The notifier id */
 #define PREF_NOTIFIER                           "notifier"
+#ifdef ENABLE_LIBNOTIFY
+#define PREF_NOTIFIER_DEFAULT                   "libnotify"
+#else
 #define PREF_NOTIFIER_DEFAULT                   "tooltip"
+#endif
 
 /* The duration of the notification (in seconds) */
 #define PREF_NOTIFICATION_TIME                  "notification-time"
