@@ -22,6 +22,9 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
+#define MPD_GLIB 1
+#include "lib/libmpdclient.h"
+
 #include "ario-debug.h"
 #include "ario-profiles.h"
 #include "preferences/ario-preferences.h"
@@ -257,7 +260,7 @@ ario_mpd_update_elapsed (gpointer data)
         ARIO_LOG_FUNCTION_START;
 
         /* If in idle mode: update elapsed time every seconds when MPD is playing */
-        if (ario_server_get_current_state() == MPD_STATUS_STATE_PLAY) {
+        if (ario_server_get_current_state() == ARIO_STATE_PLAY) {
                 ++instance->priv->elapsed;
                 g_object_set (G_OBJECT (instance), "elapsed", instance->priv->elapsed, NULL);
                 ario_server_interface_emit (ARIO_SERVER_INTERFACE (instance), server_instance);
@@ -657,8 +660,7 @@ ario_mpd_get_albums (const ArioServerCriteria *criteria)
                 }
 
                 if (entity->info.song->file) {
-                        mpd_album->path = entity->info.song->file;
-                        entity->info.song->file = NULL;
+                        mpd_album->path = g_path_get_dirname (entity->info.song->file);
                 } else {
                         mpd_album->path = NULL;
                 }
@@ -699,7 +701,7 @@ ario_mpd_get_songs (const ArioServerCriteria *criteria,
 
         for (tmp = criteria; tmp; tmp = g_slist_next (tmp)) {
                 atomic_criteria = tmp->data;
-                if (atomic_criteria->tag == MPD_TAG_ITEM_ALBUM
+                if (atomic_criteria->tag == ARIO_TAG_ALBUM
                     && !g_utf8_collate (atomic_criteria->value, ARIO_SERVER_UNKNOWN))
                         is_album_unknown = TRUE;
         }
@@ -712,7 +714,7 @@ ario_mpd_get_songs (const ArioServerCriteria *criteria,
                         mpd_addConstraintSearch (instance->priv->connection,
                                                  atomic_criteria->tag,
                                                  "");
-                else if (atomic_criteria->tag != MPD_TAG_ITEM_ALBUM
+                else if (atomic_criteria->tag != ARIO_TAG_ALBUM
                          || g_utf8_collate (atomic_criteria->value, ARIO_SERVER_UNKNOWN))
                         mpd_addConstraintSearch (instance->priv->connection,
                                                  atomic_criteria->tag,
@@ -842,13 +844,13 @@ ario_mpd_update_status (void)
                             || instance->parent.playlist_id != (gint64) instance->priv->status->playlist)
                                 g_object_set (G_OBJECT (instance), "song_id", instance->priv->status->songid, NULL);
 
-                        if (instance->parent.state != instance->priv->status->state)
+                        if ((gint) instance->parent.state != instance->priv->status->state)
                                 g_object_set (G_OBJECT (instance), "state", instance->priv->status->state, NULL);
 
                         if (instance->parent.volume != instance->priv->status->volume)
                                 g_object_set (G_OBJECT (instance), "volume", instance->priv->status->volume, NULL);
 
-                        if (instance->parent.elapsed != instance->priv->status->elapsedTime) {
+                        if ((gint) instance->parent.elapsed != instance->priv->status->elapsedTime) {
                                 g_object_set (G_OBJECT (instance), "elapsed", instance->priv->status->elapsedTime, NULL);
                                 instance->priv->elapsed = instance->priv->status->elapsedTime;
                         }
@@ -864,7 +866,7 @@ ario_mpd_update_status (void)
                         if (instance->parent.repeat != (gboolean) instance->priv->status->repeat)
                                 g_object_set (G_OBJECT (instance), "repeat", instance->priv->status->repeat, NULL);
 
-                        if (instance->parent.updatingdb != instance->priv->status->updatingDb)
+                        if ((gint) instance->parent.updatingdb != instance->priv->status->updatingDb)
                                 g_object_set (G_OBJECT (instance), "updatingdb", instance->priv->status->updatingDb, NULL);
                         instance->parent.crossfade = instance->priv->status->crossfade;
                 }
@@ -890,7 +892,7 @@ ario_mpd_get_current_song_on_server (void)
         mpd_sendCurrentSongCommand (instance->priv->connection);
         ent = mpd_getNextInfoEntity (instance->priv->connection);
         if (ent) {
-                song = ent->info.song;
+                song = (ArioServerSong *) ent->info.song;
                 ent->info.song = NULL;
                 mpd_freeInfoEntity (ent);
         }
@@ -1219,7 +1221,7 @@ ario_mpd_save_playlist (const char *name)
         if (instance->priv->support_idle && instance->priv->connection)
                 mpd_startIdle (instance->priv->connection, ario_mpd_idle_cb, NULL);
 
-        if (instance->priv->connection->error == MPD_ERROR_ACK && instance->priv->connection->errorCode == MPD_ACK_ERROR_EXIST)
+        if (instance->priv->connection->error == MPD_ERROR_1_ACK && instance->priv->connection->errorCode == MPD_ACK_ERROR_EXIST)
                 return 1;
         return 0;
 }
@@ -1295,7 +1297,7 @@ ario_mpd_get_stats (void)
         if (instance->priv->support_idle && instance->priv->connection)
                 mpd_startIdle (instance->priv->connection, ario_mpd_idle_cb, NULL);
 
-        return instance->priv->stats;
+        return (ArioServerStats *) instance->priv->stats;
 }
 
 static GList *
