@@ -306,6 +306,12 @@ ario_mpd_update_elapsed (gpointer data)
         return TRUE;
 }
 
+static void
+ario_mpd_emit_storedplaylist (gpointer not_used)
+{
+        g_signal_emit_by_name (G_OBJECT (server_instance), "storedplaylists_changed");
+}
+
 static void
 ario_mpd_idle_read (void)
 {
@@ -325,7 +331,7 @@ ario_mpd_idle_read (void)
 
         /* Stored playlists changed, update list */
         if (flags & MPD_IDLE_STORED_PLAYLIST)
-                g_signal_emit_by_name (G_OBJECT (server_instance), "storedplaylists_changed");
+                g_idle_add ((GSourceFunc) ario_mpd_emit_storedplaylist, NULL);
 }
 
 static gboolean
@@ -889,8 +895,12 @@ ario_mpd_get_songs (const ArioServerCriteria *criteria,
         mpd_search_db_songs (instance->priv->connection, exact);
         for (tmp = criteria; tmp; tmp = g_slist_next (tmp)) {
                 atomic_criteria = tmp->data;
-                if (instance->priv->support_empty_tags
-                    && !g_utf8_collate (atomic_criteria->value, ARIO_SERVER_UNKNOWN))
+                if (atomic_criteria->tag == ARIO_TAG_ANY)
+                        mpd_search_add_any_tag_constraint (instance->priv->connection,
+                                                           MPD_OPERATOR_DEFAULT,
+                                                           atomic_criteria->value);
+                else if (instance->priv->support_empty_tags
+                         && !g_utf8_collate (atomic_criteria->value, ARIO_SERVER_UNKNOWN))
                         mpd_search_add_tag_constraint (instance->priv->connection,
                                                        MPD_OPERATOR_DEFAULT,
                                                        ario_mpd_filter_tag (atomic_criteria->tag),
@@ -999,13 +1009,12 @@ ario_mpd_update_status (void)
         instance->priv->is_updating = TRUE;
 
         /* check if there is a connection */
-        if (!instance->priv->connection) {
+        if (ario_mpd_command_preinvoke ()) {
                 ario_server_interface_set_default (ARIO_SERVER_INTERFACE (instance));
         } else {
                 if (instance->priv->status)
                         mpd_status_free (instance->priv->status);
 
-                ario_mpd_command_preinvoke ();
                 instance->priv->status = mpd_run_status (instance->priv->connection);
                 ario_mpd_command_postinvoke ();
 
@@ -1312,6 +1321,7 @@ ario_mpd_insert_at (const GSList *songs,
 {
         ARIO_LOG_FUNCTION_START;
         const GSList *tmp;
+        guint offset = 0;
 
         if (ario_mpd_command_preinvoke ())
                 return;
@@ -1321,7 +1331,8 @@ ario_mpd_insert_at (const GSList *songs,
         /* For each filename :*/
         for (tmp = songs; tmp; tmp = g_slist_next (tmp)) {
                 /* Add it in the playlist*/
-                mpd_send_add_id_to (instance->priv->connection, tmp->data, pos + 1);
+                mpd_send_add_id_to (instance->priv->connection, tmp->data, pos + offset + 1);
+                ++offset;
         }
 
         mpd_command_list_end (instance->priv->connection);
@@ -1339,7 +1350,12 @@ ario_mpd_save_playlist (const char *name)
         if (ario_mpd_command_preinvoke ())
                 return 1;
 
-        ret = mpd_run_save (instance->priv->connection, name);
+        ret = !mpd_run_save (instance->priv->connection, name);
+
+        if  (mpd_connection_get_error (instance->priv->connection) != MPD_ERROR_SUCCESS) {
+                ARIO_LOG_ERROR("%s", mpd_connection_get_error_message (instance->priv->connection));
+                mpd_connection_clear_error (instance->priv->connection);
+        }
 
         ario_mpd_command_postinvoke ();
 
