@@ -177,6 +177,7 @@ enum
         FILE_COLUMN,
         GENRE_COLUMN,
         DATE_COLUMN,
+        DISC_COLUMN,
         ID_COLUMN,
         TIME_COLUMN,
         N_COLUMN
@@ -238,6 +239,7 @@ static ArioPlaylistColumn all_columns []  = {
         { FILE_COLUMN, PREF_FILE_COLUMN_SIZE, PREF_FILE_COLUMN_SIZE_DEFAULT, PREF_FILE_COLUMN_ORDER, PREF_FILE_COLUMN_ORDER_DEFAULT, PREF_FILE_COLUMN_VISIBLE, PREF_FILE_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
         { GENRE_COLUMN, PREF_GENRE_COLUMN_SIZE, PREF_GENRE_COLUMN_SIZE_DEFAULT, PREF_GENRE_COLUMN_ORDER, PREF_GENRE_COLUMN_ORDER_DEFAULT, PREF_GENRE_COLUMN_VISIBLE, PREF_GENRE_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
         { DATE_COLUMN, PREF_DATE_COLUMN_SIZE, PREF_DATE_COLUMN_SIZE_DEFAULT, PREF_DATE_COLUMN_ORDER, PREF_DATE_COLUMN_ORDER_DEFAULT, PREF_DATE_COLUMN_VISIBLE, PREF_DATE_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
+        { DISC_COLUMN, PREF_DISC_COLUMN_SIZE, PREF_DISC_COLUMN_SIZE_DEFAULT, PREF_DISC_COLUMN_ORDER, PREF_DISC_COLUMN_ORDER_DEFAULT, PREF_DISC_COLUMN_VISIBLE, PREF_DISC_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
         { -1, NULL, 0, NULL, 0, NULL, FALSE, FALSE, FALSE, FALSE, NULL }
 };
 
@@ -345,11 +347,15 @@ ario_playlist_reorder_columns (void)
         ARIO_LOG_FUNCTION_START;
         GtkTreeViewColumn *orders[N_COLUMN] = {NULL};
         GtkTreeViewColumn *current, *prev = NULL;
-        int i;
+        int i, order;
 
         /* Get an ordered list of column in orders[] thanks to the preferences */
         for (i = 0; all_columns[i].columnnb != -1; ++i)
-                orders[ario_conf_get_integer (all_columns[i].pref_order, all_columns[i].default_order)] = all_columns[i].column;
+        {
+                order = ario_conf_get_integer (all_columns[i].pref_order, all_columns[i].default_order);
+                if (order < N_COLUMN)
+                        orders[order] = all_columns[i].column;
+        }
 
         /* Move columns in the order computed in orders[] */
         for (i = 0; i < N_COLUMN; ++i) {
@@ -505,7 +511,7 @@ ario_playlist_init (ArioPlaylist *playlist)
 {
         ARIO_LOG_FUNCTION_START;
         int i;
-        const gchar *column_names []  = { " ", _("Track"), _("Title"), _("Artist"), _("Album"), _("Duration"), _("File"), _("Genre"), _("Date") };
+        const gchar *column_names []  = { " ", _("Track"), _("Title"), _("Artist"), _("Album"), _("Duration"), _("File"), _("Genre"), _("Date"), _("Disc") };
         GtkWidget *image, *close_button;
         GtkScrolledWindow *scrolled_window;
 
@@ -533,7 +539,6 @@ ario_playlist_init (ArioPlaylist *playlist)
                 ario_playlist_append_column (&all_columns[i], column_names[i]);
 
         /* Reorder columns */
-
         ario_playlist_reorder_columns ();
 
         /* Create tree model */
@@ -547,6 +552,7 @@ ario_playlist_init (ArioPlaylist *playlist)
                                                     G_TYPE_STRING,
                                                     G_TYPE_STRING,
                                                     G_TYPE_STRING,
+                                                    G_TYPE_STRING,
                                                     G_TYPE_INT,
                                                     G_TYPE_INT);
 
@@ -764,16 +770,16 @@ ario_playlist_sync_song (void)
         /* If we are still playing and the song has not changed we don't do anything */
         if (song
             && instance->priv->pos == song->pos
-            && (state == MPD_STATUS_STATE_PLAY
-                || state == MPD_STATUS_STATE_PAUSE))
+            && (state == ARIO_STATE_PLAY
+                || state == ARIO_STATE_PAUSE))
                 return;
 
         /* If there is no song playing and it was already the case before, we don't
          * do anything */
         if ((instance->priv->pos == -1
              && (!song
-                 || state == MPD_STATUS_STATE_UNKNOWN
-                 || state == MPD_STATUS_STATE_STOP)))
+                 || state == ARIO_STATE_UNKNOWN
+                 || state == ARIO_STATE_STOP)))
                 return;
 
         /* Remove the 'playing' icon from previous song */
@@ -790,8 +796,8 @@ ario_playlist_sync_song (void)
 
         /* Add 'playing' icon to new song */
         if (song
-            && state != MPD_STATUS_STATE_UNKNOWN
-            && state != MPD_STATUS_STATE_STOP) {
+            && state != ARIO_STATE_UNKNOWN
+            && state != ARIO_STATE_STOP) {
                 path = gtk_tree_path_new_from_indices (song->pos, -1);
                 if (gtk_tree_model_get_iter (GTK_TREE_MODEL (instance->priv->model), &iter, path)) {
                         gtk_list_store_set (instance->priv->model, &iter,
@@ -835,7 +841,7 @@ ario_playlist_changed_cb (ArioServer *server,
 
         /* Get current song */
         state = ario_server_get_current_state ();
-        if (state == MPD_STATUS_STATE_UNKNOWN || state == MPD_STATUS_STATE_STOP)
+        if (state == ARIO_STATE_UNKNOWN || state == ARIO_STATE_STOP)
                 current_song = NULL;
         else
                 current_song = ario_server_get_current_song ();
@@ -873,6 +879,7 @@ ario_playlist_changed_cb (ArioServer *server,
                                             DATE_COLUMN, song->date,
                                             ID_COLUMN, song->id,
                                             TIME_COLUMN, song->time,
+                                            DISC_COLUMN, song->disc,
                                             -1);
                 }
         }
@@ -1240,14 +1247,14 @@ ario_playlist_get_drop_position (const int x,
 
 static void
 ario_playlist_drop_songs (const int x, const int y,
-                          const GtkSelectionData *data)
+                          GtkSelectionData *data)
 {
         ARIO_LOG_FUNCTION_START;
         gchar **songs;
         GSList *filenames = NULL;
         int i;
 
-        songs = g_strsplit ((const gchar *) data->data, "\n", 0);
+        songs = g_strsplit ((const gchar *) gtk_selection_data_get_data (data), "\n", 0);
 
         /* Get a list of filenames */
         for (i=0; songs[i]!=NULL && g_utf8_collate (songs[i], ""); ++i)
@@ -1256,7 +1263,7 @@ ario_playlist_drop_songs (const int x, const int y,
         /* Add songs to the playlist */
         ario_server_playlist_add_songs (filenames,
                                         ario_playlist_get_drop_position (x, y),
-                                        FALSE);
+                                        PLAYLIST_ADD);
 
         g_strfreev (songs);
         g_slist_free (filenames);
@@ -1264,20 +1271,20 @@ ario_playlist_drop_songs (const int x, const int y,
 
 static void
 ario_playlist_drop_dir (const int x, const int y,
-                        const GtkSelectionData *data)
+                        GtkSelectionData *data)
 {
         ARIO_LOG_FUNCTION_START;
-        const gchar *dir = (const gchar *) data->data;
+        const gchar *dir = (const gchar *) gtk_selection_data_get_data (data);
 
         /* Add a whole directory to the playlist */
         ario_server_playlist_add_dir (dir,
                                       ario_playlist_get_drop_position (x, y),
-                                      FALSE);
+                                      PLAYLIST_ADD);
 }
 
 static void
 ario_playlist_drop_criterias (const int x, const int y,
-                              const GtkSelectionData *data)
+                              GtkSelectionData *data)
 {
         ARIO_LOG_FUNCTION_START;
         gchar **criterias_str;
@@ -1288,7 +1295,7 @@ ario_playlist_drop_criterias (const int x, const int y,
         GSList *filenames = NULL, *criterias = NULL;
 
         /* Get a list of criteria from drag data */
-        criterias_str = g_strsplit ((const gchar *) data->data, "\n", 0);
+        criterias_str = g_strsplit ((const gchar *) gtk_selection_data_get_data (data), "\n", 0);
         while (criterias_str[i] && *criterias_str[i] != '\0') {
                 nb = atoi (criterias_str[i]);
                 criteria = NULL;
@@ -1309,7 +1316,7 @@ ario_playlist_drop_criterias (const int x, const int y,
         /* Add all songs matching the list of criteria to the playlist */
         ario_server_playlist_add_criterias (criterias,
                                             ario_playlist_get_drop_position (x, y),
-                                            FALSE, -1);
+                                            PLAYLIST_ADD, -1);
 
         g_slist_foreach (criterias, (GFunc) ario_server_criteria_free, NULL);
         g_slist_free (criterias);
@@ -1327,18 +1334,18 @@ ario_playlist_drag_leave_cb (GtkWidget *widget,
         ARIO_LOG_FUNCTION_START;
 
         /* Call the appropriate functions depending on data type */
-        if (data->type == gdk_atom_intern ("text/internal-list", TRUE)) {
+        if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/internal-list", TRUE)) {
                 if (context->action & GDK_ACTION_COPY)
                         ario_playlist_copy_rows (x, y);
                 else
                         ario_playlist_move_rows (x, y);
-        } else if (data->type == gdk_atom_intern ("text/songs-list", TRUE)) {
+        } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/songs-list", TRUE)) {
                 ario_playlist_drop_songs (x, y, data);
-        } else if (data->type == gdk_atom_intern ("text/radios-list", TRUE)) {
+        } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/radios-list", TRUE)) {
                 ario_playlist_drop_songs (x, y, data);
-        } else if (data->type == gdk_atom_intern ("text/directory", TRUE)) {
+        } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/directory", TRUE)) {
                 ario_playlist_drop_dir (x, y, data);
-        } else if (data->type == gdk_atom_intern ("text/criterias-list", TRUE)) {
+        } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/criterias-list", TRUE)) {
                 ario_playlist_drop_criterias (x, y, data);
         }
 
@@ -1356,7 +1363,7 @@ ario_playlist_drag_data_get_cb (GtkWidget * widget,
 
         g_return_if_fail (selection_data != NULL);
 
-        gtk_selection_data_set (selection_data, selection_data->target, 8,
+        gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8,
                                 NULL, 0);
 }
 
@@ -1629,7 +1636,7 @@ ario_playlist_cmd_goto_playing_song (GtkAction *action,
         }
 
         /* Also go to the playing song in the souces */
-        ario_sourcemanager_goto_playling_song ();
+        ario_source_manager_goto_playling_song ();
 }
 
 void
@@ -1658,11 +1665,17 @@ ario_playlist_cmd_save (GtkAction *action,
         entry = gtk_entry_new ();
         hbox = gtk_hbox_new (FALSE, 5);
 
-        gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-        gtk_box_pack_start_defaults (GTK_BOX (hbox), entry);
+        gtk_box_pack_start (GTK_BOX (hbox),
+                            label,
+                            TRUE, TRUE,
+                            0);
+        gtk_box_pack_start (GTK_BOX (hbox),
+                            entry,
+                            TRUE, TRUE,
+                            0);
         gtk_container_set_border_width (GTK_CONTAINER (hbox), 10);
         gtk_box_set_spacing (GTK_BOX (hbox), 4);
-        gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox),
+        gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                            hbox);
         gtk_widget_show_all (dialog);
 
